@@ -78,13 +78,14 @@ print "Reading gnome-vfs.keys.in.\n";
 @expected_keys =
   (
    "can_be_executable",
-   "category",
+   "_category",
    "default_action_type",
    "icon_filename",
    "open",
    "short_list_application_ids_for_advanced_user_level",
    "short_list_application_ids_for_intermediate_user_level",
    "short_list_application_ids_for_novice_user_level",
+   "short_list_component_iids",
    "short_list_component_iids_for_advanced_user_level",
    "short_list_component_iids_for_intermediate_user_level",
    "short_list_component_iids_for_novice_user_level",
